﻿// <copyright file="IDbCommandExtensions.cs" company="DotNetLib">
//
// .netlib: http://www.codeplex.com/DotNetLib
//
// This code is released under the New BSD License.
// A copy of this license is available at:
// http://www.codeplex.com/DotNetLib/license
//
// </copyright>

namespace DotNetLib.Data
{
  using System;
  using System.Data;

  /// <summary>
  /// Extension methods for an <see cref="IDbCommand"/>.
  /// </summary>
  [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Naming", "CA1709:IdentifiersShouldBeCasedCorrectly", MessageId = "Db", Justification = "Modeling the poorly cased .NET BCL")]
  public static class IDbCommandExtensions
  {
    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static bool? ExecuteBoolean(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (bool)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static byte? ExecuteByte(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (byte)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static byte[] ExecuteBytes(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (byte[])result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static char? ExecuteChar(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (char)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static char[] ExecuteChars(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (char[])result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static DateTime? ExecuteDateTime(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (DateTime)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static decimal? ExecuteDecimal(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (decimal)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static double? ExecuteDouble(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (double)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static Guid? ExecuteGuid(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (Guid)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static short? ExecuteInt16(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (short)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static int? ExecuteInt32(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (int)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static long? ExecuteInt64(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (long)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static float? ExecuteSingle(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (float)result;
      }
    }

    /// <summary>
    /// Executes the query and returns the first column of the first row in the resultset returned by the query.
    /// </summary>
    /// <param name="command">The command to execute.</param>
    /// <returns>The value of the field.</returns>
    public static string ExecuteString(this IDbCommand command)
    {
      object result = command.ExecuteScalar();
      if (result == null || Convert.IsDBNull(result))
      {
        return null;
      }
      else
      {
        return (string)result;
      }
    }
  }
}
