﻿// <copyright file="FileInfoExtensions.cs" company="DotNetLib">
//
// .netlib: http://www.codeplex.com/DotNetLib
//
// Portions of this were part of the CodePlex "Extensions for .NET Framework"
//    project and written by Marco Minerva, mailto:marco.minerva@gmail.com
//
// This code is released under the New BSD License.
// A copy of this license is available at:
// http://www.codeplex.com/DotNetLib/license
//
// </copyright>

namespace DotNetLib.IO
{
  using System.IO;

  /// <summary>
  /// Extension methods for a <see cref="FileInfo"/>.
  /// </summary>
  public static class FileInfoExtensions
  {
    /// <summary>
    /// Adds a file to the <b>Recent Documents</b> menu using the Shell.
    /// </summary>
    /// <param name="fileInfo">The <see cref="FileInfo"/> object that represents the file to be added to the menu.</param>
    [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Justification = "Cannot add a directory to the recent items list, only files work")]
    public static void AddToRecentDocuments(this FileInfo fileInfo)
    {
      Windows.NativeMethods.SHAddToRecentDocs(fileInfo.FullName);
    }

    /// <summary>
    /// Deletes the file or directory to the recycle bin using the Shell.
    /// </summary>
    /// <param name="fileInfo">The <see cref="FileInfo"/> object that represents the file to delete.</param>
    public static void DeleteToRecycleBin(this FileSystemInfo fileInfo)
    {
      Windows.NativeMethods.DeleteToRecycleBin(fileInfo.FullName, false);
    }

    /// <summary>
    /// Deletes a file or directory to the recycle bin using the Shell.  Optional confirmation dialog.
    /// </summary>
    /// <param name="fileInfo">The <see cref="FileInfo"/> object that represents the file to delete.</param>
    /// <param name="showConfirmation">Whether to show the stock confirmation dialog for this action.</param>
    public static void DeleteToRecycleBin(this FileSystemInfo fileInfo, bool showConfirmation)
    {
      Windows.NativeMethods.DeleteToRecycleBin(fileInfo.FullName, showConfirmation);
    }
  }
}
