﻿// <copyright file="DesignerActionList.cs" company="DotNetLib">
//
// .netlib: http://www.codeplex.com/DotNetLib
//
// This code is released under the New BSD License.
// A copy of this license is available at:
// http://www.codeplex.com/DotNetLib/license
//
// </copyright>

namespace DotNetLib.Windows.Forms.Design
{
  using System.ComponentModel;
  using System.ComponentModel.Design;

  /// <summary>
  /// Provides the base class for types that define a list of items used to create a smart tag panel.
  /// </summary>
  public abstract class DesignerActionList : System.ComponentModel.Design.DesignerActionList
  {
    /// <summary>
    /// Initializes a new instance of the <see cref="DesignerActionList"/> class.
    /// </summary>
    /// <param name="component">A component related to this DesignerActionList.</param>
    protected DesignerActionList(IComponent component)
      : base(component)
    {
    }

    /// <summary>
    /// Replaces the selection with the component this list is attached to.
    /// </summary>
    protected void SelectComponent()
    {
      IComponent component = this.Component;
      if (component == null)
      {
        return;
      }

      ISelectionService service = (ISelectionService)GetService(typeof(ISelectionService));
      if (service == null)
      {
        return;
      }

      object[] components = new object[] { component };
      service.SetSelectedComponents(components, SelectionTypes.Replace);
    }

    /// <summary>
    /// Removes the component this list is attached to from the selection.
    /// </summary>
    protected void DeselectComponent()
    {
      IComponent component = this.Component;
      if (component == null)
      {
        return;
      }

      ISelectionService service = (ISelectionService)GetService(typeof(ISelectionService));
      if (service == null)
      {
        return;
      }

      object[] components = new object[] { component };
      service.SetSelectedComponents(components, SelectionTypes.Remove);
    }
  }
}
